pub struct ErrorCollector<'e> { /* private fields */ }Expand description
Error collector for custom validation rules.
When implementing your own validation rule for an object or list of elements, use the
ErrorCollector::nest method to track the current location for error reporting.
Implementations
Sourceimpl<'e> ErrorCollector<'e>
impl<'e> ErrorCollector<'e>
Sourcepub fn inner(&mut self) -> ErrorCollector<'_>
pub fn inner(&mut self) -> ErrorCollector<'_>
Produce a validator for an “inner” type. This means a type that’s nested in Rust-land, but not in the source YAML.
Sourcepub fn nest<'s, 'a>(
&'s mut self,
segment: impl Into<LocationSegment<'a>>,
) -> ErrorCollector<'s>
pub fn nest<'s, 'a>( &'s mut self, segment: impl Into<LocationSegment<'a>>, ) -> ErrorCollector<'s>
Produce a validator for a nested object property or array index.
Sourcepub fn span(&self) -> SourceSpan
pub fn span(&self) -> SourceSpan
Return the current location.
Sourcepub fn report(&mut self, diag: impl Diagnostic + Send + Sync + 'static)
pub fn report(&mut self, diag: impl Diagnostic + Send + Sync + 'static)
Report a validation error at the current location.
Any miette::Diagnostic can be used as the error value, but the recommendation for
Apollo products is to use apollo_errors, for its error code support.
Sourcepub fn report_simple(&mut self, message: impl Display)
pub fn report_simple(&mut self, message: impl Display)
Report a validation error at the current location. This is intended for one-off, simple, single-field errors pointing at the current value.
We generally recommend you use apollo_errors for errors, even configuration validation
errors, for example for its error codes.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of errors already reported.
This concerns all errors, not just errors generated in the current call to
Validate::validate or its descendents. For example, when validating the second item in
a list, .len() will include validation errors from the first item in the list.