pub struct HeaderValue(/* private fields */);Expand description
An HTTP header value parsed from configuration.
Methods from Deref<Target = HeaderValue>
Sourcepub fn to_str(&self) -> Result<&str, ToStrError>
pub fn to_str(&self) -> Result<&str, ToStrError>
Yields a &str slice if the HeaderValue only contains visible ASCII
chars.
This function will perform a scan of the header value, checking all the characters.
Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.to_str().unwrap(), "hello");Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the length of self.
This length is in bytes.
Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.len(), 5);Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the HeaderValue has a length of zero bytes.
Examples
let val = HeaderValue::from_static("");
assert!(val.is_empty());
let val = HeaderValue::from_static("hello");
assert!(!val.is_empty());Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
pub fn as_bytes(&self) -> &[u8] ⓘ
Converts a HeaderValue to a byte slice.
Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.as_bytes(), b"hello");Sourcepub fn is_sensitive(&self) -> bool
pub fn is_sensitive(&self) -> bool
Returns true if the value represents sensitive data.
Sensitive data could represent passwords or other data that should not be stored on disk or in memory. By marking header values as sensitive, components using this crate can be instructed to treat them with special care for security reasons. For example, caches can avoid storing sensitive values, and HPACK encoders used by HTTP/2.0 implementations can choose not to compress them.
Additionally, sensitive values will be masked by the Debug
implementation of HeaderValue.
Note that sensitivity is not factored into equality or ordering.
Examples
let mut val = HeaderValue::from_static("my secret");
val.set_sensitive(true);
assert!(val.is_sensitive());
val.set_sensitive(false);
assert!(!val.is_sensitive());Trait Implementations
Sourceimpl Clone for HeaderValue
impl Clone for HeaderValue
Sourcefn clone(&self) -> HeaderValue
fn clone(&self) -> HeaderValue
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for HeaderValue
impl Debug for HeaderValue
Sourceimpl Deref for HeaderValue
impl Deref for HeaderValue
Sourceimpl<'de> Deserialize<'de> for HeaderValue
impl<'de> Deserialize<'de> for HeaderValue
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
impl Eq for HeaderValue
Sourceimpl From<HeaderValue> for HeaderValue
impl From<HeaderValue> for HeaderValue
Sourcefn from(value: HeaderValue) -> Self
fn from(value: HeaderValue) -> Self
Sourceimpl FromStr for HeaderValue
impl FromStr for HeaderValue
Sourceimpl Hash for HeaderValue
impl Hash for HeaderValue
Sourceimpl JsonSchema for HeaderValue
impl JsonSchema for HeaderValue
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
$ref keyword. Read moreSourceimpl PartialEq for HeaderValue
impl PartialEq for HeaderValue
Sourcefn eq(&self, other: &HeaderValue) -> bool
fn eq(&self, other: &HeaderValue) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HeaderValue
impl Serialize for HeaderValue
impl StructuralPartialEq for HeaderValue
Sourceimpl Validate for HeaderValue
impl Validate for HeaderValue
Sourcefn validate<'a>(&self, _errors: ErrorCollector<'a>)
fn validate<'a>(&self, _errors: ErrorCollector<'a>)
validate accepts all inputs.Auto Trait Implementations
impl !Freeze for HeaderValue
impl RefUnwindSafe for HeaderValue
impl Send for HeaderValue
impl Sync for HeaderValue
impl Unpin for HeaderValue
impl UnsafeUnpin for HeaderValue
impl UnwindSafe for HeaderValue