pub struct SocketAddrV6(/* private fields */);Expand description
An IPv6 socket address parsed from configuration.
Methods from Deref<Target = SocketAddrV6>
1.0.0 · Sourcepub fn ip(&self) -> &Ipv6Addr
pub fn ip(&self) -> &Ipv6Addr
Returns the IP address associated with this socket address.
Examples
use std::net::{SocketAddrV6, Ipv6Addr};
let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 0);
assert_eq!(socket.ip(), &Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1));1.0.0 · Sourcepub fn port(&self) -> u16
pub fn port(&self) -> u16
Returns the port number associated with this socket address.
Examples
use std::net::{SocketAddrV6, Ipv6Addr};
let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 0);
assert_eq!(socket.port(), 8080);1.0.0 · Sourcepub fn flowinfo(&self) -> u32
pub fn flowinfo(&self) -> u32
Returns the flow information associated with this address.
This information corresponds to the sin6_flowinfo field in C’s netinet/in.h,
as specified in IETF RFC 2553, Section 3.3.
It combines information about the flow label and the traffic class as specified
in IETF RFC 2460, respectively Section 6 and Section 7.
Examples
use std::net::{SocketAddrV6, Ipv6Addr};
let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 10, 0);
assert_eq!(socket.flowinfo(), 10);1.0.0 · Sourcepub fn scope_id(&self) -> u32
pub fn scope_id(&self) -> u32
Returns the scope ID associated with this address.
This information corresponds to the sin6_scope_id field in C’s netinet/in.h,
as specified in IETF RFC 2553, Section 3.3.
Examples
use std::net::{SocketAddrV6, Ipv6Addr};
let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 78);
assert_eq!(socket.scope_id(), 78);Trait Implementations
Sourceimpl Clone for SocketAddrV6
impl Clone for SocketAddrV6
Sourcefn clone(&self) -> SocketAddrV6
fn clone(&self) -> SocketAddrV6
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SocketAddrV6
Sourceimpl Debug for SocketAddrV6
impl Debug for SocketAddrV6
Sourceimpl Deref for SocketAddrV6
impl Deref for SocketAddrV6
Sourceimpl<'de> Deserialize<'de> for SocketAddrV6
impl<'de> Deserialize<'de> for SocketAddrV6
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for SocketAddrV6
impl Display for SocketAddrV6
impl Eq for SocketAddrV6
Sourceimpl From<SocketAddrV6> for SocketAddrV6
impl From<SocketAddrV6> for SocketAddrV6
Sourcefn from(value: SocketAddrV6) -> Self
fn from(value: SocketAddrV6) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for SocketAddrV6
impl FromStr for SocketAddrV6
Sourceimpl Hash for SocketAddrV6
impl Hash for SocketAddrV6
Sourceimpl JsonSchema for SocketAddrV6
impl JsonSchema for SocketAddrV6
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SocketAddrV6
impl PartialEq for SocketAddrV6
Sourcefn eq(&self, other: &SocketAddrV6) -> bool
fn eq(&self, other: &SocketAddrV6) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SocketAddrV6
impl Serialize for SocketAddrV6
impl StructuralPartialEq for SocketAddrV6
Sourceimpl Validate for SocketAddrV6
impl Validate for SocketAddrV6
Sourcefn validate<'a>(&self, _errors: ErrorCollector<'a>)
fn validate<'a>(&self, _errors: ErrorCollector<'a>)
The default implementation of
validate accepts all inputs.Auto Trait Implementations
impl Freeze for SocketAddrV6
impl RefUnwindSafe for SocketAddrV6
impl Send for SocketAddrV6
impl Sync for SocketAddrV6
impl Unpin for SocketAddrV6
impl UnsafeUnpin for SocketAddrV6
impl UnwindSafe for SocketAddrV6